# This file is generated by objective.metadata
#
# Last update: Wed Feb 23 12:28:54 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$SCStreamErrorDomain$SCStreamFrameInfoContentRect$SCStreamFrameInfoContentScale$SCStreamFrameInfoDirtyRects$SCStreamFrameInfoDisplayTime$SCStreamFrameInfoScaleFactor$SCStreamFrameInfoStatus$"""
enums = """$SCFrameStatusBlank@2$SCFrameStatusComplete@0$SCFrameStatusIdle@1$SCFrameStatusStarted@4$SCFrameStatusStopped@5$SCFrameStatusSuspended@3$SCStreamErrorAttemptToConfigState@-3810$SCStreamErrorAttemptToStartStreamState@-3807$SCStreamErrorAttemptToStopStreamState@-3808$SCStreamErrorAttemptToUpdateFilterState@-3809$SCStreamErrorFailedApplicationConnectionInterrupted@-3805$SCStreamErrorFailedApplicationConnectionInvalid@-3804$SCStreamErrorFailedNoMatchingApplicationContext@-3806$SCStreamErrorFailedToStart@-3802$SCStreamErrorInternalError@-3811$SCStreamErrorInvalidParameter@-3812$SCStreamErrorMissingEntitlements@-3803$SCStreamErrorNoCaptureSource@-3815$SCStreamErrorNoDisplayList@-3814$SCStreamErrorNoWindowList@-3813$SCStreamErrorRemovingStream@-3816$SCStreamErrorUserDeclined@-3801$SCStreamOutputTypeScreen@0$"""
misc.update(
    {
        "SCStreamErrorCode": NewType("SCStreamErrorCode", int),
        "SCFrameStatus": NewType("SCFrameStatus", int),
        "SCStreamOutputType": NewType("SCStreamOutputType", int),
    }
)
misc.update({"SCStreamFrameInfo": NewType("SCStreamFrameInfo", str)})
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"stream:didOutputSampleBuffer:ofType:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"^{opaqueCMSampleBuffer=}"},
                4: {"type": b"q"},
            },
        },
    )
    r(
        b"NSObject",
        b"stream:didStopWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"SCShareableContent",
        b"getShareableContentExcludingDesktopWindows:onScreenWindowsOnly:completionHandler:",
        {
            "arguments": {
                2: {"type": b"Z"},
                3: {"type": b"Z"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                },
            }
        },
    )
    r(
        b"SCShareableContent",
        b"getShareableContentExcludingDesktopWindows:onScreenWindowsOnlyAboveWindow:completionHandler:",
        {
            "arguments": {
                2: {"type": b"Z"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                },
            }
        },
    )
    r(
        b"SCShareableContent",
        b"getShareableContentExcludingDesktopWindows:onScreenWindowsOnlyBelowWindow:completionHandler:",
        {
            "arguments": {
                2: {"type": b"Z"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                },
            }
        },
    )
    r(
        b"SCShareableContent",
        b"getShareableContentWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"SCStream",
        b"addStreamOutput:type:sampleHandlerQueue:error:",
        {"retval": {"type": b"Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"SCStream",
        b"removeStreamOutput:type:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"SCStream",
        b"startCaptureWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SCStream",
        b"stopCaptureWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SCStream",
        b"updateConfiguration:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SCStream",
        b"updateContentFilter:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"SCStreamConfiguration",
        b"minimumFrameInterval",
        {"retval": {"type": b"{_CMTime=qiIq}"}},
    )
    r(b"SCStreamConfiguration", b"scalesToFit", {"retval": {"type": b"Z"}})
    r(
        b"SCStreamConfiguration",
        b"setMinimumFrameInterval:",
        {"arguments": {2: {"type": b"{_CMTime=qiIq}"}}},
    )
    r(b"SCStreamConfiguration", b"setScalesToFit:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SCStreamConfiguration", b"setShowsCursor:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SCStreamConfiguration", b"showsCursor", {"retval": {"type": b"Z"}})
    r(b"SCWindow", b"isOnScreen", {"retval": {"type": b"Z"}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase
import ScreenCaptureKit


class TestSCShareableContent(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(ScreenCaptureKit.SCWindow.isOnScreen)

        self.assertArgIsBlock(
            ScreenCaptureKit.SCShareableContent.getShareableContentWithCompletionHandler_,
            0,
            b"v@@",
        )

        self.assertArgIsBOOL(
            ScreenCaptureKit.SCShareableContent.getShareableContentExcludingDesktopWindows_onScreenWindowsOnly_completionHandler_,
            0,
        )
        self.assertArgIsBOOL(
            ScreenCaptureKit.SCShareableContent.getShareableContentExcludingDesktopWindows_onScreenWindowsOnly_completionHandler_,
            1,
        )
        self.assertArgIsBlock(
            ScreenCaptureKit.SCShareableContent.getShareableContentExcludingDesktopWindows_onScreenWindowsOnly_completionHandler_,
            2,
            b"v@@",
        )

        self.assertArgIsBOOL(
            ScreenCaptureKit.SCShareableContent.getShareableContentExcludingDesktopWindows_onScreenWindowsOnlyBelowWindow_completionHandler_,
            0,
        )
        self.assertArgIsBlock(
            ScreenCaptureKit.SCShareableContent.getShareableContentExcludingDesktopWindows_onScreenWindowsOnlyBelowWindow_completionHandler_,
            2,
            b"v@@",
        )

        self.assertArgIsBOOL(
            ScreenCaptureKit.SCShareableContent.getShareableContentExcludingDesktopWindows_onScreenWindowsOnlyAboveWindow_completionHandler_,
            0,
        )
        self.assertArgIsBlock(
            ScreenCaptureKit.SCShareableContent.getShareableContentExcludingDesktopWindows_onScreenWindowsOnlyAboveWindow_completionHandler_,
            2,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase
import ScreenCaptureKit


class TestSCError(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(ScreenCaptureKit.SCStreamErrorCode)

    def test_constants(self):
        self.assertEqual(ScreenCaptureKit.SCStreamErrorUserDeclined, -3801)
        self.assertEqual(ScreenCaptureKit.SCStreamErrorFailedToStart, -3802)
        self.assertEqual(ScreenCaptureKit.SCStreamErrorMissingEntitlements, -3803)
        self.assertEqual(
            ScreenCaptureKit.SCStreamErrorFailedApplicationConnectionInvalid, -3804
        )
        self.assertEqual(
            ScreenCaptureKit.SCStreamErrorFailedApplicationConnectionInterrupted, -3805
        )
        self.assertEqual(
            ScreenCaptureKit.SCStreamErrorFailedNoMatchingApplicationContext, -3806
        )
        self.assertEqual(ScreenCaptureKit.SCStreamErrorAttemptToStartStreamState, -3807)
        self.assertEqual(ScreenCaptureKit.SCStreamErrorAttemptToStopStreamState, -3808)
        self.assertEqual(
            ScreenCaptureKit.SCStreamErrorAttemptToUpdateFilterState, -3809
        )
        self.assertEqual(ScreenCaptureKit.SCStreamErrorAttemptToConfigState, -3810)
        self.assertEqual(ScreenCaptureKit.SCStreamErrorInternalError, -3811)
        self.assertEqual(ScreenCaptureKit.SCStreamErrorInvalidParameter, -3812)
        self.assertEqual(ScreenCaptureKit.SCStreamErrorNoWindowList, -3813)
        self.assertEqual(ScreenCaptureKit.SCStreamErrorNoDisplayList, -3814)
        self.assertEqual(ScreenCaptureKit.SCStreamErrorNoCaptureSource, -3815)
        self.assertEqual(ScreenCaptureKit.SCStreamErrorRemovingStream, -3816)



import objc
from PyObjCTools.TestSupport import TestCase
import ScreenCaptureKit


class TestSCStreamHelper(ScreenCaptureKit.NSObject):
    def stream_didOutputSampleBuffer_ofType_(self, a, b, c):
        pass


class TestSCStream(TestCase):
    def test_typed_enum(self):
        self.assertIsTypedEnum(ScreenCaptureKit.SCStreamFrameInfo, str)

    def test_enum_types(self):
        self.assertIsEnumType(ScreenCaptureKit.SCFrameStatus)
        self.assertIsEnumType(ScreenCaptureKit.SCStreamOutputType)

    def test_constants(self):
        self.assertEqual(ScreenCaptureKit.SCFrameStatusComplete, 0)
        self.assertEqual(ScreenCaptureKit.SCFrameStatusIdle, 1)
        self.assertEqual(ScreenCaptureKit.SCFrameStatusBlank, 2)
        self.assertEqual(ScreenCaptureKit.SCFrameStatusSuspended, 3)
        self.assertEqual(ScreenCaptureKit.SCFrameStatusStarted, 4)
        self.assertEqual(ScreenCaptureKit.SCFrameStatusStopped, 5)

        self.assertEqual(ScreenCaptureKit.SCStreamOutputTypeScreen, 0)

        self.assertIsInstance(ScreenCaptureKit.SCStreamFrameInfoStatus, str)
        self.assertIsInstance(ScreenCaptureKit.SCStreamFrameInfoDisplayTime, str)
        self.assertIsInstance(ScreenCaptureKit.SCStreamFrameInfoScaleFactor, str)
        self.assertIsInstance(ScreenCaptureKit.SCStreamFrameInfoContentScale, str)
        self.assertIsInstance(ScreenCaptureKit.SCStreamFrameInfoContentRect, str)
        self.assertIsInstance(ScreenCaptureKit.SCStreamFrameInfoDirtyRects, str)

    def test_methods(self):
        self.assertResultIsBOOL(ScreenCaptureKit.SCStreamConfiguration.scalesToFit)
        self.assertArgIsBOOL(ScreenCaptureKit.SCStreamConfiguration.setScalesToFit_, 0)

        self.assertResultIsBOOL(ScreenCaptureKit.SCStreamConfiguration.showsCursor)
        self.assertArgIsBOOL(ScreenCaptureKit.SCStreamConfiguration.setShowsCursor_, 0)

        self.assertArgIsBlock(
            ScreenCaptureKit.SCStream.updateContentFilter_completionHandler_, 1, b"v@"
        )
        self.assertArgIsBlock(
            ScreenCaptureKit.SCStream.updateConfiguration_completionHandler_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            ScreenCaptureKit.SCStream.startCaptureWithCompletionHandler_,
            0,
            b"v@",
        )
        self.assertArgIsBlock(
            ScreenCaptureKit.SCStream.stopCaptureWithCompletionHandler_, 0, b"v@"
        )

        self.assertResultIsBOOL(
            ScreenCaptureKit.SCStream.addStreamOutput_type_sampleHandlerQueue_error_
        )
        self.assertArgIsOut(
            ScreenCaptureKit.SCStream.addStreamOutput_type_sampleHandlerQueue_error_, 3
        )

        self.assertResultIsBOOL(
            ScreenCaptureKit.SCStream.removeStreamOutput_type_error_
        )
        self.assertArgIsOut(ScreenCaptureKit.SCStream.removeStreamOutput_type_error_, 2)

    def test_protocols(self):
        objc.protocolNamed("SCStreamDelegate")
        objc.protocolNamed("SCStreamOutput")

    def test_proto_methods(self):
        self.assertArgHasType(
            TestSCStreamHelper.stream_didOutputSampleBuffer_ofType_,
            1,
            b"^{opaqueCMSampleBuffer=}",
        )
        self.assertArgHasType(
            TestSCStreamHelper.stream_didOutputSampleBuffer_ofType_,
            2,
            objc._C_NSInteger,
        )



"""
Python mapping for the ScreenCaptureKit framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import CoreMedia
import objc
from . import _metadata, _ScreenCaptureKit

sys.modules["ScreenCaptureKit"] = mod = objc.ObjCLazyModule(
    "ScreenCaptureKit",
    "com.apple.ScreenCaptureKit",
    objc.pathForFramework("/System/Library/Frameworks/ScreenCaptureKit.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (
        _ScreenCaptureKit,
        CoreMedia,
    ),
)

del sys.modules["ScreenCaptureKit._metadata"]
